var context_8c =
[
    [ "object_entry", "structobject__entry.html", "structobject__entry" ],
    [ "DEFAULT_CLOCK_MAX_QUANTUM", "context_8c.html#a0079001bae95c9c9b2624aa2bfd37d1b", null ],
    [ "DEFAULT_CLOCK_MIN_QUANTUM", "context_8c.html#a04d3c7ec92b4a78d9a77fe2790be9e9a", null ],
    [ "DEFAULT_CLOCK_POWER_OF_TWO_QUANTUM", "context_8c.html#a320dd4d70f273497536a27da6cbbc195", null ],
    [ "DEFAULT_CLOCK_QUANTUM", "context_8c.html#a92a629b69a1b0f877fc0ee658a2953ac", null ],
    [ "DEFAULT_CLOCK_RATE", "context_8c.html#a97e89412f3549291a46f26b87ce44fa3", null ],
    [ "DEFAULT_LINK_MAX_BUFFERS", "context_8c.html#af8fb6f642966400172a5c0d253a669b5", null ],
    [ "DEFAULT_MEM_ALLOW_MLOCK", "context_8c.html#a66a2ddaf05dcf9696aa9d494191ea6c1", null ],
    [ "DEFAULT_MEM_WARN_MLOCK", "context_8c.html#a899f8b5950491d2538eadbdf4fff905b", null ],
    [ "DEFAULT_VIDEO_HEIGHT", "context_8c.html#a39f078c4b4708b93f1ba4d9d2753d07f", null ],
    [ "DEFAULT_VIDEO_RATE_DENOM", "context_8c.html#a21a24c4dc8767aa4bb139f52120c12eb", null ],
    [ "DEFAULT_VIDEO_RATE_NUM", "context_8c.html#a1556603b94e169527fdb5318fbf077d3", null ],
    [ "DEFAULT_VIDEO_WIDTH", "context_8c.html#aa21ee0c65b1e9925619ea51375bed99c", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "context_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "pw_context_add_listener", "group__pw__context.html#ga44d2d1b5d618438873016c764584f1e5", null ],
    [ "pw_context_add_spa_lib", "group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e", null ],
    [ "pw_context_debug_port_params", "context_8c.html#a48516aac937b8d35fb63f4e62a78d253", null ],
    [ "pw_context_destroy", "group__pw__context.html#ga41fdab6368603144f0911541182713a1", null ],
    [ "pw_context_find_export_type", "group__pw__context.html#ga718d8f124cf5f06c0f21b15a0b34e0db", null ],
    [ "pw_context_find_format", "context_8c.html#a68cdc41b6bc8400932d7f77ff0a601eb", null ],
    [ "pw_context_find_global", "group__pw__context.html#gae01b3e37bd9c02da61ac4bad64dc7217", null ],
    [ "pw_context_find_port", "context_8c.html#a4144a0c95100a2ae6cde42d30eb293bb", null ],
    [ "pw_context_find_spa_lib", "group__pw__context.html#ga8970b7ecc709a445142eec2742ac4f3a", null ],
    [ "pw_context_for_each_global", "group__pw__context.html#gaaa07217fcfeba4dd0a0269ff313a75d7", null ],
    [ "pw_context_get_conf_section", "group__pw__context.html#ga44f13e3b82c3410300156b243889b803", null ],
    [ "pw_context_get_main_loop", "group__pw__context.html#gab3832ce0cf064dea0ba7f502a16a55aa", null ],
    [ "pw_context_get_object", "group__pw__context.html#ga5455f68cb23daa8557d884ad342b518d", null ],
    [ "pw_context_get_properties", "group__pw__context.html#ga87b444d4781c05318b30cf1931043ae4", null ],
    [ "pw_context_get_support", "group__pw__context.html#gad73656626f5f88f5ace1569b11073b22", null ],
    [ "pw_context_get_user_data", "group__pw__context.html#ga00b5fe35e858f993eacc29fed285f377", null ],
    [ "pw_context_get_work_queue", "group__pw__context.html#gad466760a74623341ac33d267581ddf39", null ],
    [ "pw_context_load_spa_handle", "group__pw__context.html#ga0a44b5fcb071f0e82004b929af3d1a90", null ],
    [ "pw_context_new", "group__pw__context.html#gab40dbe45a3b8282f99c4d27863411e5f", null ],
    [ "pw_context_recalc_graph", "context_8c.html#af6af5924b93ff1fa11bc8732096319dc", null ],
    [ "pw_context_register_export_type", "group__pw__context.html#ga39a9e29ddc0cad4ced7d6034a64e3aff", null ],
    [ "pw_context_set_object", "group__pw__context.html#ga1e67973ea8236ff8bc6125a437b79a76", null ],
    [ "pw_context_update_properties", "group__pw__context.html#ga48011f6ba07333a33f880778da4a1c86", null ],
    [ "PW_LOG_TOPIC_EXTERN", "context_8c.html#ae49faa78046fb5bc620a98b06f0a881e", null ]
];